pro get_ssc_best, indexin, iout, dataout, _extra=_extra, $
       maxdt=maxdt, actdt=actdt, filtb=filtb, half=half, quart=quart, $
       later_only=later_only, earlier_only=earlier_only, $
       status=status, expand_days=expand_days, recurse=recurse, $
       delta_sec=delta_sec, debug=debug, sxt_index=sxt_index, $
       sscfiles=sscfiles
;
;+
;   Name: get_ssc_best
;
;   Purpose: return 'index,data' for "best" SSC matching 
;
;   Input Parameters:
;      indexin - index/time to match
;
;   Output Parameters:
;      iout, dataout - the corresponding SSC/SSS index,data pair
;
;   Keyword Parameters:
;      maxdt - maximum "acceptable" delta-time in hours
;      actdt - acutal delta-time from input time
;      filtb - optional filter b (integer 2: Al1, 3: AlMg)
;      res   - optional resolution (integer: 1: half, 2: quarter)
;      half  - switch, synonym for res=1
;      quarter - switch, synonym for res=2
;      expand_days - number of days to allow expanding search 
;      status - 1: match found/returned in iout,dataout
;               0: no match found with desired constraints
;      sscfiles - optional list of files to consider 
;
;   Calling Sequence:
;      IDL> get_ssc_best, timein, index, data [/half, /quart, filtb=xx]
;
;   History:
;      23-Jan-2001 - simplify some auto-context (ssw_fov_context) and SSC work
;
;-  

common get_ssc_best, recdays
;
;
later=keyword_set(later_only)
earlier=keyword_set(earlier_only)
debug=keyword_set(debug)
if n_elements(expand_days) eq 0 then expand_days=0
if n_elements(recurse) eq 0 then recdays=1 else recdays=recdays+1
status=0
if n_elements(maxdt) eq 0 then maxdt=24       ; hours
case 1 of
   later: window=[0,maxdt] +   (recdays*[0,24])
   earlier: window=[-(maxdt),0] + (recdays*[-24,0])
   else: window=replicate(maxdt(0),2)*[-1,1] +     (recdays*[-24,24])
endcase

time_window, indexin(0), t0, t1, hours=window

if data_chk(sscfiles,/string) then ssc=sscfiles else $
   ssc=ssc_files(t0, t1, _extra=_extra)
if ssc(0) eq '' then begin 
   box_message,'No ssc files in desired window'
   if expand_days gt recdays then begin
      box_message,'expanding search window'
      get_ssc_best,indexin,iout, dataout, _extra=_extra, $
         filtb=filtb, half=half, quarter=quarter, /recurse, recdays=recdays, expand_days=expand_days 
   endif else begin
     box_message,' Giving up...'
     retall
   endelse
endif

rd_roadmap,ssc,rmap

case 1 of 
   keyword_set(filtb):fb=strtrim(filtb,2)
   else: fb='2,3'
endcase 
   
case 1 of 
   keyword_set(quarter): res='2'
   keyword_set(half):    res='1'
   else: res='1,2'
endcase

ss=struct_where(rmap,test=['gt_filtb='+fb, 'gt_res='+res],count,/quiet)
if count eq 0 then begin
   box_message,'No SSC images match your desired parameters...'
   return
endif


delta_sec=ssw_deltat(rmap(ss),ref=indexin(0))

case 1 of 
   earlier: sss=last_nelem(where(delta_sec le 0)) 
   later: sss=(where(delta_sec gt 0))(0)
   else: sss=where(abs(delta_sec) eq min(abs(delta_sec)))
endcase
actdt=(delta_sec(sss)/3600.)(0)         ; delta-hours between input/output

status=abs(actdt) le maxdt

rd_xda, ssc,ss(sss(0)),sxt_index
read_sxt, ssc, ss(sss(0)), iout, dataout
if debug then stop,'before return'
return
end
 

